// ============= Elemente vorab generieren =====================

/* CSS-Angaben für diese Elemente bei "popup.css" */

const abdecker = document.createElement('div');
abdecker.id = 'abdecker';

// die animierte "Sanduhr", die anzeigt, dass ein großes Bild geladen wird
const abdeckerSanduhr = document.createElement('img');
abdeckerSanduhr.id = 'abdeckerSanduhr';
abdeckerSanduhr.src = 'p/waiting_white.svg';

const grossBild = document.createElement('figure');
grossBild.id = 'grossBild';
const grossBildImg = document.createElement('img');
const grossBildFigcaption = document.createElement('figcaption');

const schliesser = document.createElement('span');
schliesser.id = 'schliesser';
schliesser.textContent = '×';
schliesser.role = 'button';
schliesser.tabIndex = '0'; // Schreibweise in JS beachten!
schliesser.title = 'Großbild schliessen';

// zusammenbauen und einfügen
grossBild.appendChild(grossBildImg);
grossBild.appendChild(grossBildFigcaption);
grossBild.appendChild(schliesser);
abdecker.appendChild(abdeckerSanduhr);
abdecker.appendChild(grossBild);
document.body.appendChild(abdecker);

// ============== Ende der Generierung ===============

function grossBildZeigen(ereignis) {
    // Link wird damit nicht ausgeführt
    ereignis.preventDefault();

    // ACHTUNG: "currentTarget" geht, "target" NICHT!

    const mySrc = ereignis.currentTarget.href;
    grossBildImg.src = mySrc;

    // Kind vom Kind…
    const myBeschreibung =
        ereignis.currentTarget.firstElementChild.firstElementChild.dataset.beschreibung;

    grossBildImg.alt = myBeschreibung;
    grossBildFigcaption.textContent = myBeschreibung;

    abdeckerSanduhr.classList.add('sichtbar');
    abdecker.classList.add('sichtbar');

    abdecker.addEventListener(
        'transitionend',
        function () {
            // console.log("Abdecker-Transition beended!");
            grossBild.classList.add('sichtbar');
        },
        { once: true } // damit läuft dieser "addEventListener" nur einmal und addiert sich nicht auf
    );

    // ================= Zusatzinfos abfragen ===================

    /*

    // Abfragen unterschiedlicher Sachen, die sich jeweils innerhalb eines <a>-Elements befinden
    console.log('innerHTML: ' + ereignis.currentTarget.innerHTML);
    console.log('href: ' + ereignis.currentTarget.href);

    // folgende Sachen sind keine direkten Kinder des <a>-Elements,
    // sondern Kinder des Kindes, deswegen das "firstElementChild.firstElementChild"
    console.log(
        'firstElementChild.src: ' + ereignis.currentTarget.firstElementChild.firstElementChild.src
    );
    console.log(
        'firstElementChild.width: ' +
            ereignis.currentTarget.firstElementChild.firstElementChild.width
    );
    console.log(
        'dataset-beschreibung: ' +
            ereignis.currentTarget.firstElementChild.firstElementChild.dataset.beschreibung
    );
    console.log('alt: ' + ereignis.currentTarget.firstElementChild.firstElementChild.alt);

    */
}

function grossBildWeg() {
    abdeckerSanduhr.classList.remove('sichtbar');
    grossBild.classList.remove('sichtbar');

    grossBild.addEventListener(
        'transitionend',
        function () {
            // console.log("grossBild-Transition beended!");
            abdecker.classList.remove('sichtbar');

            // "leeres" Bild - damit nicht beim nächsten "grossBildZeigen"
            // noch teilweise das alte Bild gezeigt wird und dann während
            // der Transition ausgetauscht wird - das stört sehr!
            // besonders merkbar, wenn die Bilder vom Server geladen werden
            // und eine langsame Internet-Verbindung besteht
            grossBildImg.src = '';
        },
        { once: true }
    );
}

// "×" zum Schliessen des grossBild
schliesser.addEventListener('click', grossBildWeg);
abdecker.addEventListener('click', grossBildWeg);
